@@ -15,6 +15,12 @@ pub trait Annotate {
 /// doing the annotation process in one step.
 pub struct Annotator(Vec<Box<dyn Annotate + Sync>>);
 
+impl Annotator {
+    pub fn add(&mut self, annotator: Box<dyn Annotate + Sync>) -> &mut Annotator {
+        self.0.push(annotator);
+        self
+    }
+}
 impl Annotate for Annotator {
     fn annotate(&self, doc: &mut Document) {
         for annotator in &self.0 {
@@ -25,12 +31,32 @@ impl Annotate for Annotator {
 
 impl Default for Annotator {
     fn default() -> Self {
-        Self(vec![
-            Box::new(TinyDocument::default()),
-            Box::new(ShortSentences::default()),
-            Box::new(ContentDetector::with_defaults().unwrap()),
-            Box::new(Header::default()),
-            Box::new(Noisy::default()),
-        ])
+        Self(vec![])
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use crate::transformers::Annotate;
+
+    use super::Annotator;
+
+    #[test]
+    fn test_default() {
+        let a = Annotator::default();
+        assert_eq!(a.0.len(), 0);
+    }
+
+    #[test]
+    fn test_add() {
+        struct MockAnnotate {}
+        impl Annotate for MockAnnotate {
+            fn annotate(&self, _: &mut crate::pipelines::oscardoc::types::Document) {}
+        }
+
+        let mut a = Annotator::default();
+        a.add(Box::new(MockAnnotate {}));
+
+        assert_eq!(a.0.len(), 1);
     }
 }
